# Dynalite

An unofficial Philips Dynalite DyNET interface

## Getting Started

A very basic interface to the dynalite system. Using .setPreset(area,preset,fadeTime) you can change area presets.

### Prerequisites

You must have an RS485 to IP device somewhere on your Dynalite network. Your network must only use DyNET (not DyNET2). Don't waste money on official Dynalite 485 interfaces, almost any IP<->485 interface will work fine.

## Versioning

We use [SemVer](http://semver.org/) for versioning. For the versions available, see the [tags on this repository](https://github.com/troykelly/python-dynalite/tags).

## Authors

* **Troy Kelly** - *Initial work* - [troykelly](https://github.com/troykelly)

See also the list of [contributors](https://github.com/troykelly/python-dynalite/contributors) who participated in this project.

## License

This project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details

## Acknowledgments

* Dynalite for not embracing technology at all and forcing the build of this
